const APIKEY = '2c21e65a76f343bc803123042242608'; // Replace with your API key
const btn = document.getElementById('btn');
const input = document.getElementById('input');

const cityName = document.getElementById('city-name');
const countryName = document.getElementById('countryName');
const localtime = document.getElementById('loc-time');
const temp = document.getElementById('temp');
const sup = document.getElementById('sup');
const weatherIcon = document.getElementById('icon');
const outputCard = document.getElementById('outputCard');
const themeToggleBtn = document.getElementById('theme-toggle');

// Toggle dark mode on and off
themeToggleBtn.addEventListener('click', () => {
    document.body.classList.toggle('dark-mode');
    document.querySelector('.container').classList.toggle('dark-mode');
    document.querySelector('.title-card').classList.toggle('dark-mode');
    document.querySelector('.card').classList.toggle('dark-mode');
    outputCard.classList.toggle('dark-mode');
    btn.classList.toggle('dark-mode');
    themeToggleBtn.classList.toggle('dark-mode');
    weatherIcon.classList.toggle('dark-mode');
});

// Show message on the screen
const showMessage = (message) => {
    const alertBox = document.createElement('div');
    alertBox.className = 'alert';
    alertBox.innerText = message;
    document.body.appendChild(alertBox);
    setTimeout(() => alertBox.remove(), 3000);
};

// Fetch weather data
async function getWeatherData(city) {
    try {
        const response = await fetch(`https://api.weatherapi.com/v1/current.json?key=${APIKEY}&q=${city}&aqi=no`);
        if (!response.ok) {
            throw new Error(`API Error: ${response.statusText}`);
        }
        return await response.json();
    } catch (error) {
        console.error(`Error fetching weather data: ${error.message}`);
        showMessage("Failed to fetch weather data. Check your input or try later.");
    }
}

btn.addEventListener('click', async () => {
    const city = input.value.trim();

    if (!city) {
        showMessage("Please enter a city name");
        return;
    }

    // Disable the button and show loading text
    btn.disabled = true;
    btn.innerText = "Loading...";

    const weatherData = await getWeatherData(city);

    // Enable the button back after data fetch
    btn.disabled = false;
    btn.innerText = "Get Weather";

    // Check if weather data exists
    if (!weatherData || weatherData.error) {
        showMessage("City not found. Please try again.");
        outputCard.style.display = 'none';
        return;
    }

    // Display weather data
    cityName.innerText = `${weatherData.location.name}, ${weatherData.location.region}`;
    countryName.innerText = weatherData.location.country;
    temp.innerText = weatherData.current.temp_c;
    sup.innerText = '°C';
    localtime.innerText = `Local time: ${weatherData.location.localtime}`;
    weatherIcon.src = weatherData.current.condition.icon;
    weatherIcon.alt = weatherData.current.condition.text;

    // Show the output card
    outputCard.style.display = 'block';
});
